declare const module: {
    namespaced: boolean;
    state: {
        /**
         * @property catalogs
         * @type Array
         * @description An array of catalogs.
         */
        catalogs: never[];
        datasetCounts: {};
        loading: boolean;
        searchParameters: {
            query: string;
            limit: number;
            offset: number;
            facets: never[];
            facetOperator: string;
            facetGroupOperator: string;
            sort: string;
        };
        availableFacets: never[];
        page: number;
        pageCount: number;
        catalogsCount: number;
    };
    actions: {
        /**
         * @description Load all catalogs matching the given parameters.
         * @param commit
         * @param state
         * @param options {Object} - Given search parameters
         * @param options.query {String} - The given query string
         * @param options.facets {Array} - The active facets
         * @param options.limit {Number} - The maximum amount of catalogs to fetch
         * @param options.page {Number} - The current page
         * @param options.sort {String} - The sort method to use
         * @param options.append {Boolean} - Decides whether current catalogs in state will be replaced or fetched catalogs appended.
         */
        loadCatalogs({ commit, state }: {
            commit: any;
            state: any;
        }, { query, limit, page, sort, facetOperator, facetGroupOperator, facets, append, }: {
            query?: any;
            limit?: any;
            page?: any;
            sort?: any;
            facetOperator?: any;
            facetGroupOperator?: any;
            facets?: any;
            append?: boolean | undefined;
        }): Promise<unknown>;
        /**
         * @description Loads more catalogs.
         * @param commit
         * @param state
         * @param {number} amount - The amount of catalogs to add.
         */
        loadAdditionalCatalogs({ commit, state }: {
            commit: any;
            state: any;
        }): void;
        /**
         * @description Autocomplete a query String by using a autocompletion service
         * @param commit
         * @param q {String} The Query to autocomplete
         */
        autocompleteQuery({ commit }: {
            commit: any;
        }, q: any): Promise<unknown> | undefined;
        /**
         * @description Replace the current state facets by the given facets
         * @param commit
         * @param facets {Array} - The given facets
         */
        setFacets({ commit }: {
            commit: any;
        }, facets: any): void;
        /**
         * @description Add the given facet to the states facets.
         * @param commit
         * @param params {Object} - The wrapped action parameters.
         * @param params.field {String} - The field of the given facet
         * @param params.facet {String} - The facet to add
         */
        addFacet({ commit }: {
            commit: any;
        }, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param params {Object} - The wrapped action parameters.
         * @param params.field {String} - The field of the given facet
         * @param params.facet {String} - The facet to remove
         */
        removeFacet({ commit }: {
            commit: any;
        }, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param operator {String} - The facet operator to set. Possible Operators : ['AND', 'OR'].
         */
        setFacetOperator({ commit }: {
            commit: any;
        }, operator: any): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param operator {String} - The facet operator to set. Possible Operators : ['AND', 'OR'].
         */
        setFacetGroupOperator({ commit }: {
            commit: any;
        }, operator: any): void;
        /**
         * @description Handles page changes by through URL query.
         * @param commit
         * @param state
         * @param page {String} The given page number as a String
         */
        setPage({ commit }: {
            commit: any;
        }, page: any): void;
        setPageCount({ commit }: {
            commit: any;
        }, count: any): void;
        /**
         * @description Replace the current state query by the given query
         * @param commit
         * @param query {String} - The given query
         */
        setQuery({ commit }: {
            commit: any;
        }, query: any): void;
        /**
         * @description Replace the current sort method
         * @param commit
         * @param sort {String} - The given sort method to use now
         */
        setSort({ commit }: {
            commit: any;
        }, sort: any): void;
        setLimit({ commit }: {
            commit: any;
        }, amount?: number): void;
        setLoading({ commit }: {
            commit: any;
        }, isLoading: any): void;
        setCatalogs({ commit }: {
            commit: any;
        }, catalogs: any): void;
        setCatalogsCount({ commit }: {
            commit: any;
        }, count: any): void;
    };
    mutations: {
        SET_catalogS(state: any, data: any): void;
        ADD_catalogS(state: any, data: any): void;
        SET_LIMIT(state: any, limit: any): void;
        SET_OFFSET(state: any, offset: any): void;
        SET_FACETS(state: any, facets: any): void;
        ADD_FACET(state: any, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        REMOVE_FACET(state: any, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        SET_AVAILABLE_FACETS(state: any, facets: any): void;
        SET_catalogS_COUNT(state: any, catalogsCount: any): void;
        SET_FACET_OPERATOR(state: any, operator: any): void;
        SET_FACET_GROUP_OPERATOR(state: any, operator: any): void;
        SET_PAGE(state: any, page: any): void;
        SET_PAGE_COUNT(state: any, count: any): void;
        SET_QUERY(state: any, query: any): void;
        SET_SORT(state: any, sort: any): void;
        SET_LOADING(state: any, isLoading: any): void;
    };
    getters: {
        getCatalogs: (state: any) => any;
        getCatalogsCount: (state: any) => any;
        getQuery: (state: any) => any;
        getLimit: (state: any) => any;
        getLoading: (state: any) => any;
        getOffset: (state: any) => any;
        getFacets: (state: any) => any;
        getFacetOperator: (state: any) => any;
        getFacetGroupOperator: (state: any) => any;
        getAvailableFacets: (state: any) => any[];
        getPage: (state: any) => any;
        getPageCount: (state: any) => any;
        getSort: (state: any) => any;
    };
};
export default module;
